----------------------
-- Intercept Tasking--
----------------------

-- adapted from:
-- Name: TAD-A2A-010 - AREAS - Intercept Task
-- Author: FlightControl
-- Date Created: 13 Mar 2017
--
-- This mission demonstrates the dynamic task dispatching for Air to Air operations.
-- Intruders are flying towards the EWR units. 
-- The detection method used is the DETECTION_AREAS method, which groups detected targets per detected area.
-- 
-- Observe the planes flying towards the EWR.
-- Upon detection, an INTERCEPT task should be created.
-- Join the task and destroy the intruders.
-- Check if the task is successful after destroying the target.
-- 
-- 

_SETTINGS:SetImperial()
_SETTINGS:SetA2A_BRAA()
_SETTINGS:SetPlayerMenuOff()

local HQ = GROUP:FindByName( "HQ", "Control" )

-- function COMMANDCENTER:New( CommandCenterPositionable, CommandCenterName )

local CommandCenter = COMMANDCENTER:New( HQ , "Control" )
CommandCenter:SetFlashStatus(false)

-- function SCORING:New( GameName )

local Scoring = SCORING:New( "A2A Interception" )

-- function MISSION:New( CommandCenter, MissionName, MissionPriority, MissionBriefing, MissionCoalition )

local Mission = MISSION
  :New( CommandCenter, "Intercept Tasks", "GCI", "An INTERCEPT task will be created. Join the task and fly the mission. BRA and target information provided by text.", coalition.side.BLUE )
  :AddScoring( Scoring )

local EWRSet = SET_GROUP:New():FilterPrefixes( "Blue EWR" ):FilterCoalitions("blue"):FilterStart()

local EWRDetection = DETECTION_AREAS:New( EWRSet, 6000 )
EWRDetection:SetFriendliesRange( 100000 ) -- 100 km
EWRDetection:SetRefreshTimeInterval( 30 )

local AttackGroups = SET_GROUP:New():FilterCoalitions( "blue" ):FilterPrefixes( "Intercept" ):FilterStart()

TaskDispatcher = TASK_A2A_DISPATCHER:New( Mission, AttackGroups, EWRDetection )
TaskDispatcher:SetRefreshTimeInterval( 30 )
